@@ -1,14 +1,15 @@
 from abc import ABC, abstractmethod
+import json
+
 import warnings
 import time
 from datetime import datetime
 from pathlib import Path
 from typing import Any, Tuple, Dict
 
-# Third-party libraries
+# Third-party
 import numpy as np
 import pandas as pd
-import matplotlib
 from rich import print
 from sklearn.model_selection import (
     train_test_split,
@@ -27,8 +28,7 @@ from sklearn.compose import ColumnTransformer
 from imblearn.over_sampling import SMOTE
 from imblearn.pipeline import Pipeline as ImbPipeline
 
-matplotlib.use("Agg")
-# Local imports
+# Local
 from .models import models
 from .options import Options
 from .utils import (
@@ -63,7 +63,6 @@ from .feature_importances import (
 # / Local imports =============================================================
 # ================Warnings=====================================================
 warnings.filterwarnings("ignore")
-warnings.filterwarnings("ignore", message="resource_tracker:.*")
 
 
 # =================================Core Process================================
@@ -134,16 +133,41 @@ def evaluate_model(
     return y_pred, y_proba, metrics
 
 
+class TargetColumnNameNotFound(Exception):
+    pass
+
+
+class TargetColumnNotBinary(Exception):
+    pass
+
+
 def prepare_data(
     df: pd.DataFrame, options: Options, output_area: Any = None
 ) -> tuple[pd.Series, pd.Series, pd.DataFrame]:
 
     print_report_initial(df, options, output_area=output_area)
-    if options.target_name not in df.columns:
-        warnings.warn(
-            f"Target name '{options.target_name}' not found in DataFrame columns. Using the first column as target."
-        )
+    target_name_was = options.target_name
+    # If target_name is None, use the first column
+    if options.target_name is None:
         options.target_name = df.columns[0]
+        msg = f"No target column specified. Using the first column: '{options.target_name}' as target."
+        warnings.warn(msg)
+        print(msg)
+        time.sleep(2)
+
+    if options.target_name not in df.columns:
+        msg = f"Target name '{options.target_name}' not found in DataFrame columns."
+        raise TargetColumnNameNotFound(msg)
+
+    # Check if the target column is suitable for binary classification
+    target_values = df[options.target_name].dropna().unique()
+    if len(target_values) != 2:
+        if target_name_was is None:
+            msg = f"Target name was not specified. Using the first column: '{options.target_name}' as target."
+        target_values_str = ", ".join(map(str, (list(target_values[0:3]) + ["..."])))
+        msg += f"\nTarget column '{options.target_name}' is not binary (unique values: {target_values_str}). Please provide a binary target column."
+        raise TargetColumnNotBinary(msg)
+
     df[options.target_name] = pd.to_numeric(df[options.target_name], downcast="integer")
     local_print_df(df.head(), output_area=output_area)
     if options.numerical_cols is None:
@@ -211,7 +235,7 @@ class ActionAbstract:
             save_path=folder / f"shap_force_{model.__class__.__name__}.png"
         )
 
-    def execute(self) -> None:
+    def execute(self) -> "ActionAbstract":
 
         df = self.get_df()
         if self.name == "Fresh":
@@ -298,10 +322,12 @@ class ActionAbstract:
                 y_test=y_test,
                 output_area=self.output_area,
             )
+            model_results_df = pd.DataFrame([model_results_dict])
+            print(model_results_df)
             save_results_individual(
                 self.df_final,
                 model_name,
-                pd.DataFrame([model_results_dict]),
+                model_results_df,
                 self.options,
             )
             results.append(model_results_dict)
@@ -314,6 +340,10 @@ class ActionAbstract:
                 output_area=self.output_area,
                 plot_area=self.plot_area,
             )
+        return self
+
+    def __call__(self, *args, **kwargs):
+        return self.execute(*args, **kwargs)
 
 
 class ActionFresh(ActionAbstract):
