@@ -12,6 +12,7 @@ from .options import Options
 
 
 def local_print(*args, **kwargs):
+
     if "output_area" in kwargs:
         output_area = kwargs["output_area"]
     else:
@@ -33,6 +34,7 @@ def local_print_df(*args, **kwargs):
     try:
         for arg in args:
             if output_area is not None and isinstance(arg, pd.DataFrame):
+
                 output_area.dataframe(arg)
                 shown = True
             elif output_area is not None and isinstance(arg, pd.Series):
@@ -74,16 +76,16 @@ def results_report(results, df, options, output_area=None, plot_area=None, save=
             "ROC AUC", ascending=False
         )
     )
-    # 6. Detailed analysis of the best model
     best_model_result = results_df.loc[results_df["ROC AUC"].idxmax()]
     local_print(
         f"\n   Best Model: {best_model_result['Model']} (ROC AUC: {best_model_result['ROC AUC']:.4f})",
         output_area=output_area,
     )
-    local_print("\Detailed report:", output_area=output_area)
+    # local_print("\Detailed report:", output_area=output_area)
     report = pd.DataFrame(best_model_result["Classification Report"])
-    local_print_df(results_df, output_area=output_area)
-    local_print_df(report, output_area=output_area)
+    print(results_df)
+    print(report)
+
     if save:
         save_results(
             df, "Together", results_df, best_model_result, report, options=options
