@@ -5,11 +5,13 @@ import sys
 import io
 import pandas as pd
 from pathlib import Path
-from spml2.options import Options
-
 import importlib.util
 import warnings
 
+from spml2.options import Options
+from spml2.utils import get_data
+
+
 warnings.filterwarnings("ignore", module="pyarrow")
 
 
@@ -63,7 +65,11 @@ sampling_strategy = st.sidebar.text_input(
     "SMOTE Sampling Strategy", value=SAMPLING_STRATEGY
 )
 n_splits = st.sidebar.number_input("CV Splits", min_value=2, value=N_SPLITS)
-input_folder = st.text_input("Input folder", value=str(ROOT))
+input_folder = st.text_input(
+    "Input folder",
+    value=str(ROOT),
+    help="You can enter an absolute path here to select a different data folder.",
+)
 
 if st.button("Quit App"):
     st.warning(
@@ -75,28 +81,14 @@ st.title("SPML2 User Interface")
 
 def process_with_output(options, models, output_area, plot_area):
     from spml2.core import Process
-    import sys
-    import io
-    from contextlib import redirect_stdout
 
-    buf = io.StringIO()
-    with redirect_stdout(buf):
-        Process(options, models=models, output_area=output_area, plot_area=plot_area)
-    st.session_state["output_buffer"] += buf.getvalue()
+    Process(options, models=models, output_area=output_area, plot_area=plot_area)
 
 
 def process_cache_with_output(options, models, output_area, plot_area):
     from spml2.core import Process_cache
-    import sys
-    import io
-    from contextlib import redirect_stdout
 
-    buf = io.StringIO()
-    with redirect_stdout(buf):
-        Process_cache(
-            options, models=models, output_area=output_area, plot_area=plot_area
-        )
-    st.session_state["output_buffer"] += buf.getvalue()
+    Process_cache(options, models=models, output_area=output_area, plot_area=plot_area)
 
 
 if os.path.isdir(input_folder):
@@ -111,7 +103,6 @@ else:
     selected_file = None
 
 workflow = st.radio("Choose workflow", ["Run fresh", "Process cache"])
-st.subheader("Current Options")
 
 current_options = {
     "test_mode": test_mode,
@@ -143,9 +134,6 @@ if "output_buffer" not in st.session_state:
     st.session_state["output_buffer"] = ""
 
 
-from spml2.utils import get_data
-
-
 def get_info_df(selected_file, options):
     df = get_data(options)
 
@@ -187,7 +175,3 @@ if st.button("Run"):
         st.success("Done!")
     else:
         st.error("Please select a file.")
-
-# Show the buffered output in a text area
-st.subheader("Console Output Log")
-st.text_area("Output", st.session_state["output_buffer"], height=300)
